@@ -1,10 +1,11 @@
+# -*- coding: utf-8 -*-
+
 import numpy as np
 from numba import typed, types
 
-from npbrain import profile
 from npbrain.core.neuron import Neurons
 from npbrain.core.synapse import Synapses
-from npbrain.utils import helper
+from npbrain.utils import helper, profile
 
 __all__ = [
     'Monitor',
@@ -32,6 +33,8 @@ class Monitor(object):
 class SpikeMonitor(Monitor):
     """Monitor class to record spikes.
 
+    Parameters
+    ----------
     target : Neurons
         The neuron group to monitor.
     """
@@ -71,6 +74,8 @@ class SpikeMonitor(Monitor):
 class StateMonitor(Monitor):
     """Monitor class to record states.
 
+    Parameters
+    ----------
     target : Neurons, Synapses
         The object to monitor.
     vars : str, list, tuple
@@ -92,10 +97,10 @@ class StateMonitor(Monitor):
         assert isinstance(vars, (list, tuple))
         vars = tuple(vars)
         for var in vars:
-            if var not in target.vars:
+            if var not in target.var2index:
                 raise ValueError('Variable "{}" is not in target "{}".'.format(var, target))
         self.vars = vars
-        self.vars_idx = np.array([target.vars[v] for v in vars])
+        self.vars_idx = np.array([target.var2index[v] for v in vars])
 
         # fake initialization
         for k in self.vars:
@@ -128,7 +133,7 @@ class StateMonitor(Monitor):
         super(StateMonitor, self).__init__(target)
 
     def target_index_by_vars(self):
-        return self.target.var_index[self.vars_idx]
+        return self.target.var2index_array[self.vars_idx]
 
     def init_state(self, length):
         assert isinstance(length, int)
@@ -172,7 +177,7 @@ def raster_plot(mon, times=None):
         if hasattr(mon, 'spike_time'):
             time = mon.spike_time[elements]
         else:
-            assert times is not None
+            assert times is not None, 'Must provide "times" when StateMonitor has no "spike_time" attribute.'
             time = times[elements[0]]
     elif isinstance(mon, SpikeMonitor):
         index = np.array(mon.index)
