@@ -1,7 +1,8 @@
+# -*- coding: utf-8 -*-
 
 
 # conn.py
-# from npbrain.utils.conn import *
+from npbrain.utils.conn import *
 
 # input_factory.py
 from npbrain.utils.input_factory import *
@@ -12,11 +13,14 @@ from npbrain.utils.helper import *
 # measure.py
 from npbrain.utils.measure import *
 
+# profile.py
+from npbrain.utils.profile import *
+
 # run.py
 from npbrain.utils.run import *
 
 # vis.py
-# from npbrain.utils.vis import *
+from npbrain.utils.vis import *
 
 
 
